.. talkGooder documentation master file, created by
   sphinx-quickstart on Thu Oct  3 22:58:08 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.



talkGooder documentation
========================

.. include:: ../README.md
   :parser: myst_parser.sphinx_

Functions
---------

.. autosummary::
   :nosignatures:   
   
   talkgooder.aAn :no-index:
   talkgooder.isAre :no-index:
   talkgooder.num2word :no-index:
   talkgooder.plural :no-index:
   talkgooder.possessive :no-index:

-----

.. automodule:: talkgooder
    :members:

.. toctree::
   :maxdepth: 2
   :caption: Contents:
